@@ -7,9 +7,10 @@ class EsRequest:
     _aggregation: bool
     _page: int
     _size: int
+    _with_analytics: bool
 
     def __init__(self, search_term: str, filters: List[str] = None,
-                 aggregation: bool = False, page: int = 1, size: int = 10):
+                 aggregation: bool = False, page: int = 1, size: int = 10, with_analytics: bool = False):
         """
         A class used to wrap all necessary input for the search endpoint.
 
@@ -18,12 +19,14 @@ class EsRequest:
         :param aggregation: indicate if the result should be aggregated or not
         :param page: number of page
         :param size: number of item per page
+        :param with_analytics: indicate if the result should have analytics or not
         """
         self._search_term = search_term
         self._filters = filters
         self._aggregation = aggregation
         self._page = page
         self._size = size
+        self._with_analytics = with_analytics
 
     @property
     def search_term(self):
@@ -44,3 +47,7 @@ class EsRequest:
     @property
     def size(self):
         return self._size
+
+    @property
+    def with_analytics(self):
+        return self._with_analytics
