@@ -1,3 +1,3 @@
 class Identifiers:
-    identifier_field_id = "mine.dc_identifier.id:"
+    identifier_field_id = "mine.dc_identifier.\\*:"
     files_id_field = "origin.files.id:"
