@@ -36,7 +36,8 @@ class Mine:
             'f[]': self._es_request.filters,
             'a': self._es_request.aggregation,
             'p': self._es_request.page,
-            's': self._es_request.size
+            's': self._es_request.size,
+            'wa': self._es_request.with_analytics
         }
 
         if self._internal_token is not None:
@@ -51,7 +52,7 @@ class Mine:
         response = Response(Search(), result.json())
 
         return response
-
+    '''
     @staticmethod
     def get_word_count(identifiers: List[Tuple[str, List[str]]]):
         """
@@ -66,18 +67,21 @@ class Mine:
         payload_identifier = []
 
         if identifiers:
-            for work_id, file_id in identifiers:
-                if work_id and file_id and ('' not in file_id):
+            for work_id in identifiers:
+                if work_id:
                     # making lucene query string for word count search
                     # make string for work identifier on the basis of identifier string and value
                     w = f'{Identifiers.identifier_field_id}"{work_id}"'
+                    #w1 = f'{Identifiers.doi}"{work_id}"'
                     # make string for file id on the base of file identifier string and value then concat every file id
                     # separated by OR operator
-                    f = '({0})'.format(" OR ".join([Identifiers.files_id_field + '"{0}"'.format(w) for w in file_id]))
+                    #f = '({0})'.format(" OR ".join([Identifiers.files_id_field + '"{0}"'.format(w) for w in file_id]))
                     # concat work id and file id separated by AND operator
-                    c = f'{w} AND {f}'
+                    c = f'{w}'
+                    #c1 = f'{w1}'
                     # add each string into payload_identifier list
                     payload_identifier.append(c)
+                    #payload_identifier.append(c1)
         # concat each string in payload_identifier separated by OR operator
         query = " OR ".join(['({0})'.format(i) for i in payload_identifier])
 
@@ -105,8 +109,8 @@ class Mine:
                     response.append(words)
 
         return response
-
-    @staticmethod
+    '''
+    '''@staticmethod
     def get_entities(identifiers: List[Tuple[str, List[str]]]):
         """
         Call the get_entities endpoint with parameters provided list of identifiers tuple, which have
@@ -159,28 +163,22 @@ class Mine:
                     response.append(topics)
 
         return response
-
+    '''
     def get_identifiers(self) -> Response:
         """
         Call the get_identifiers endpoint
 
-        :return: the result return list of identifiers and file ids
+        :return: the result return list of identifiers
         """
         result = self.search()
 
         response = []
         for hit in result.hits:
-            identifiers = tuple
             identifier = str
-            file_ids = []
-            files = hit['origin']['files']
-            for file in files:
-                for k in hit['mine']['dc_identifier']:
-                    identifier = hit['mine']['dc_identifier'][k]
-                    break
-                file_ids.append(file['id'])
-            identifiers = (identifier, file_ids)
-            response.append(identifiers)
+            for k in hit['mine']['dc_identifier']:
+                identifier = hit['mine']['dc_identifier'][k]
+                break
+            response.append(identifier)
 
         return response
 
